@@ -10,7 +10,7 @@ from .file import FileSystemMap
 from .users import ToggleBookmarkAction
 
 
-class CreateDefaultFileSystemItemsAction(flow.Action):
+class CreateDefaultFileSystemItemsAction_XX(flow.Action):
 
     _department = flow.Parent()
 
@@ -116,6 +116,49 @@ class CreateDefaultFileSystemItemsAction(flow.Action):
         self._department.files.touch()
 
 
+class CreateDefaultFileSystemItemsAction(flow.Action):
+
+    _department = flow.Parent()
+
+    def _ensure_file(self, name, extension):
+        files = self._department.files
+
+        if not files.has_mapped_name('%s_%s' % (name, extension)):
+            files.create_file.file_name.set(name)
+            files.create_file.file_format.set(extension)
+            files.create_file.run(None)
+    
+    def _ensure_folder(self, name):
+        files = self._department.files
+
+        if not files.has_mapped_name(name):
+            files.create_folder.folder_name.set(name)
+            files.create_folder.run(None)
+    
+    def needs_dialog(self):
+        return False
+
+    def run(self, button):
+        if button == 'Cancel':
+            return
+
+        settings = get_contextual_dict(self._department, 'settings')
+        default_files = self.root().project().admin.project_settings.default_files
+
+        names = default_files['%s_%s' % (settings['context'], settings['department'])].file_names.get()
+        names = names.replace(' ', '').split(',')
+
+        for filename in names:
+            name, ext = os.path.splitext(filename)
+
+            if ext:
+                self._ensure_file(name, ext[1:])
+            else:
+                self._ensure_folder(name)
+        
+        self._department.files.touch()
+
+
 class Department(flow.Object):
 
     _parent = flow.Parent()
