@@ -264,10 +264,16 @@ def get_real_files(paths, flow_project):
 
     for folder, files in folders.items():
         files = list(set(files))
-        file_type = Folder if len(files) > 1 else File
-
-        file = file_type.create_from_path(folder, flow_project)
-        real_files.append(file)
+        
+        if len(files) > 1:
+            item = Folder.create_from_path(folder, flow_project)
+        else:
+            item = File.create_from_path(folder, flow_project)
+            
+            if not item.exists():
+                item = Folder.create_from_path(folder, flow_project)
+            
+        real_files.append(item)
 
     return real_files
 
