@@ -1290,7 +1290,7 @@ class UploadPlayblastToKitsu(flow.Action):
     current_task_status = flow.Computed()
     target_task_type = flow.Computed()
     target_task_status = flow.Param('Work In Progress', KitsuTaskStatus)
-    comment = flow.SessionParam().ui(editor='textarea')
+    comment = flow.SessionParam("").ui(editor='textarea')
     
     def __init__(self, parent, name):
         super(UploadPlayblastToKitsu, self).__init__(parent, name)
@@ -1331,7 +1331,26 @@ class UploadPlayblastToKitsu(flow.Action):
         user = kitsu_api.get_user()
         task = kitsu_api.get_task(self._kitsu_entity, task_type)
         
-        if user is None or task is None or not kitsu_api.user_is_assigned(user, task):
+        if user is None:
+            self.message.set((
+                "<h2><font color=#D5000D>It seems you (%s) have no "
+                "user profile on Kitsu.</font></h2>Please contact the "
+                "support on the chat" % self.root().project().get_user()
+            ))
+            return ['Cancel']
+        
+        if task is None:
+            self.message.set((
+                "<h2><font color=#D5000D>This file is not linked to any "
+                "task on Kitsu.</font></h2>"
+            ))
+            return ['Cancel']
+        
+        # Check if user is assigned to the task or have sufficient rights
+        valid_user_role = (user['role'] in ['admin', 'manager'])
+        is_assigned = kitsu_api.user_is_assigned(user, task)
+        
+        if not is_assigned and not valid_user_role:
             self.message.set((
                 "<h2><font color=#D5000D>You (%s) are not assigned to "
                 "the task this file has been created for.</font></h2>"
@@ -1339,7 +1358,18 @@ class UploadPlayblastToKitsu(flow.Action):
             ))
             return ['Cancel']
         
-        self.message.set("<h2>Upload playblast to Kitsu</h2>")
+        msg = "<h2>Upload playblast to Kitsu</h2>"
+        user_roles = {
+            'admin': 'studio manager',
+            'manager': 'supervisor'
+        }
+        
+        if valid_user_role and not is_assigned:
+            msg += (
+                "As %s, you can upload a preview for this file."
+                % user_roles[user['role']]
+            )
+        self.message.set(msg)
         
         return ['Upload', 'Cancel']
     
@@ -1370,13 +1400,21 @@ class UploadPlayblastToKitsu(flow.Action):
         file_path = self._file.get_revision(self.revision_name.get()).get_path()
         kitsu_api = self.root().project().kitsu_api()
         
-        kitsu_api.upload_preview(
+        success = kitsu_api.upload_preview(
             kitsu_entity=self._kitsu_entity,
             task_type_name=self.target_task_type.get(),
             task_status_name=self.target_task_status.get(),
             file_path=self._file.get_revision(self.revision_name.get()).get_path(),
             comment=self.comment.get(),
         )
+        
+        if not success:
+            self.message.set((
+                "<h2>Upload playblast to Kitsu</h2>"
+                "<font color=#D5000D>An error occured "
+                "while uploading the preview.</font>"
+            ))
+            return self.get_result(close=False)
 
 
 class RequestTrackedFileAction(flow.Action):
