@@ -3,7 +3,7 @@ import sys
 import platform
 import subprocess
 from pathlib import Path
-import time
+from datetime import datetime
 
 from kabaret import flow
 from kabaret.subprocess_manager.runner_factory import Runner, logger
@@ -69,15 +69,16 @@ class BaseRunner(Runner):
         if not os.path.exists(self.get_log_path()):
             os.mkdir(self.get_log_path())
 
+        tznow = datetime.now().astimezone().strftime("%Y-%m-%dT%H-%M-%S%z")
         log_out_path = "%s/%s_%s.log" % (
             self.get_log_path(),
             self.runner_name(),
-            time.time(),
+            tznow,
         )
         log_err_path = "%s/%s_%s_error.log" % (
             self.get_log_path(),
             self.runner_name(),
-            time.time(),
+            tznow,
         )
 
         with open(log_out_path, "w+") as out, open(log_err_path, "w+") as err:
